/*
 * Event.h

 *
 *  Created on: 30 giu 2016
 *  Author: Giuseppe Cacciatore
 */

#ifndef EVENT_H_
#define EVENT_H_

#include <fstream>
#include <iostream>
#include <string>
#include <cstdlib>
#include <sstream>
#include <vector>
#include <cmath>
#include <stdlib.h>
#include <map>
#include <list>
#include <algorithm>
#include <iomanip>
#include <time.h>

#include "../Headers/Utilities.h"
#include "../Headers/ClockManagement.h"

using namespace std;

// Structure for the list of events
// - - - - - - - - - - - - -
// the event corresponds to a user arriving in a given position (point)
// of the map at a given time

struct Event{

	int id_user;                /**< User ID */
	Location loc;               /**< Location of the event */
	tm timestamp;              /**< Time of the event */

    Event(int A, Location B, tm C):id_user(A), loc(B), timestamp (C){}
};

typedef std::list<Event> Events;
typedef std::map<int, list<int> > GraphCityMap;

/**
 * It compares two Events
 * Inputs: Events lhs and Events rhs
 * Output: boolean value of the comparison
 */
bool eventComparator(const Event& lhs, const Event& rhs);

/**
 * Creates lists of events, ordered by UserID and time
 */
Events creatingListOfEvents(int num_users, Users usersM, Users::iterator it_usersM, StreetPoint stpM,StreetPoint::iterator it_stpM, GraphCityMap grcM, GraphCityMap::iterator it_grcM, string typeOfAntennas, int days);

/**
 * Creates lists of events, ordered by UserID and time slots
 */
Events creatingListOfEventsSlots(int num_users, Users usersM, Users::iterator it_usersM, StreetPoint stpM,StreetPoint::iterator it_stpM, GraphCityMap grcM, GraphCityMap::iterator it_grcM, string typeOfAntennas);

/**
 * Reads lists of events
 *
 */
Events readListOfEvents ();
#endif /* EVENT_H_ */
